==> fastybird-exchange-0.11.0.tar.gz: fastybird-exchange-0.11.0/README.md <==
# FastyBird exchange plugin

[![Build Status](https://badgen.net/github/checks/FastyBird/exchange/master?cache=300&style=flast-square)](https://github.com/FastyBird/exchange/actions)
[![Licence](https://badgen.net/github/license/FastyBird/exchange?cache=300&style=flast-square)](https://github.com/FastyBird/exchange/blob/master/LICENSE.md)
[![Code coverage](https://badgen.net/coveralls/c/github/FastyBird/exchange?cache=300&style=flast-square)](https://coveralls.io/r/FastyBird/exchange)

![PHP](https://badgen.net/packagist/php/FastyBird/exchange?cache=300&style=flast-square)
[![Latest stable](https://badgen.net/packagist/v/FastyBird/exchange/latest?cache=300&style=flast-square)](https://packagist.org/packages/FastyBird/exchange)
[![Downloads total](https://badgen.net/packagist/dt/FastyBird/exchange?cache=300&style=flast-square)](https://packagist.org/packages/FastyBird/exchange)
[![PHPStan](https://img.shields.io/badge/PHPStan-enabled-brightgreen.svg?style=flat-square)](https://github.com/phpstan/phpstan)

![Python](https://badgen.net/pypi/python/fastybird-exchange?cache=300&style=flat-square)
[![Python latest stable](https://badgen.net/pypi/v/fastybird-exchange?cache=300&style=flat-square)](https://pypi.org/project/fastybird-exchange/)
[![Python downloads month](https://img.shields.io/pypi/dm/fastybird-exchange?cache=300&style=flat-square)](https://pypi.org/project/fastybird-exchange/)
[![Black](https://img.shields.io/badge/black-enabled-brightgreen.svg?style=flat-square)](https://github.com/psf/black)
[![MyPy](https://img.shields.io/badge/mypy-enabled-brightgreen.svg?style=flat-square)](http://mypy-lang.org)

## What is FastyBird exchange plugin?

This is a combined plugin for [Nette framework](https://nette.org) and [Python](https://www.python.org) which is
defining exchange data bus for [FastyBird](https://www.fastybird.com) IoT services

## Installation

### PHP based project:

The best way to install **fastybird/exchange** is using [Composer](http://getcomposer.org/):

```sh
$ composer require fastybird/exchange
```

### Python based project:

The best way to install **fastybird-exchange** is using [Pip](https://pip.pypa.io/en/stable/):

```sh
$ pip install fastybird-exchange
```

## Documentation

Learn how to consume & publish messages
in [documentation](https://github.com/FastyBird/exchange/blob/master/.docs/en/index.md).

***
Homepage [https://www.fastybird.com](https://www.fastybird.com) and
repository [https://github.com/FastyBird/exchange](https://github.com/FastyBird/exchange).

==> fastybird-exchange-0.33.0.tar.gz: fastybird-exchange-0.33.0/README.md <==
# FastyBird exchange library

[![Build Status](https://badgen.net/github/checks/FastyBird/exchange/master?cache=300&style=flast-square)](https://github.com/FastyBird/exchange/actions)
[![Licence](https://badgen.net/github/license/FastyBird/exchange?cache=300&style=flast-square)](https://github.com/FastyBird/exchange/blob/master/LICENSE.md)
[![Code coverage](https://badgen.net/coveralls/c/github/FastyBird/exchange?cache=300&style=flast-square)](https://coveralls.io/r/FastyBird/exchange)

![PHP](https://badgen.net/packagist/php/FastyBird/exchange?cache=300&style=flast-square)
[![Latest stable](https://badgen.net/packagist/v/FastyBird/exchange/latest?cache=300&style=flast-square)](https://packagist.org/packages/FastyBird/exchange)
[![Downloads total](https://badgen.net/packagist/dt/FastyBird/exchange?cache=300&style=flast-square)](https://packagist.org/packages/FastyBird/exchange)
[![PHPStan](https://img.shields.io/badge/PHPStan-enabled-brightgreen.svg?style=flat-square)](https://github.com/phpstan/phpstan)

![Python](https://badgen.net/pypi/python/fastybird-exchange?cache=300&style=flat-square)
[![Python latest stable](https://badgen.net/pypi/v/fastybird-exchange?cache=300&style=flat-square)](https://pypi.org/project/fastybird-exchange/)
[![Python downloads month](https://img.shields.io/pypi/dm/fastybird-exchange?cache=300&style=flat-square)](https://pypi.org/project/fastybird-exchange/)
[![Black](https://img.shields.io/badge/black-enabled-brightgreen.svg?style=flat-square)](https://github.com/psf/black)
[![MyPy](https://img.shields.io/badge/mypy-enabled-brightgreen.svg?style=flat-square)](http://mypy-lang.org)

## What is FastyBird exchange library?

This is library for [FastyBird IoT](https://www.fastybird.com) ecosystem which is
implementing data exchange services.

## Installation

### PHP based project:

The best way to install **fastybird/exchange** is using [Composer](http://getcomposer.org/):

```sh
$ composer require fastybird/exchange
```

### Python based project:

The best way to install **fastybird-exchange** is using [Pip](https://pip.pypa.io/en/stable/):

```sh
$ pip install fastybird-exchange
```

## Documentation

Learn how to consume & publish messages
in [documentation](https://github.com/FastyBird/exchange/blob/master/.docs/en/index.md).

***
Homepage [https://www.fastybird.com](https://www.fastybird.com) and
repository [https://github.com/FastyBird/exchange](https://github.com/FastyBird/exchange).
